sys_execve

Function sys_execve 

pub fn sys_execve(
    _abi: &mut LinuxRiscv64Abi,
    trapframe: &mut Trapframe,
) -> usize
Linux execve system call implementation

This system call executes a program specified by the given path, replacing the current process image with a new one. It also allows passing arguments and environment variables to the new program.

Arguments

  • abi: LinuxRiscv64Abi context
  • trapframe: Trapframe containing syscall arguments

Returns

  • 0 on success
  • usize::MAX (Linux -1) on error