pub fn sys_getrandom(
_abi: &mut LinuxRiscv64Abi,
trapframe: &mut Trapframe,
) -> usizeExpand description
Linux sys_getrandom implementation
Fills the user buffer with random bytes from the kernel pool.
pub fn sys_getrandom(
_abi: &mut LinuxRiscv64Abi,
trapframe: &mut Trapframe,
) -> usizeLinux sys_getrandom implementation
Fills the user buffer with random bytes from the kernel pool.