sys_statx

Function sys_statx 

pub fn sys_statx(abi: &mut LinuxRiscv64Abi, trapframe: &mut Trapframe) -> usize
Linux sys_statx implementation for Scarlet VFS v2

Gets extended file status relative to a directory file descriptor (dirfd) and path. If dirfd == AT_FDCWD, uses the current working directory as the base. Supports AT_EMPTY_PATH for file-descriptor based queries.