pub fn sys_exec(_abi: &mut LinuxRiscv64Abi, trapframe: &mut Trapframe) -> usizeExpand description
Linux sys_exec system call implementation Executes a program specified by the given path, replacing the current process image with a new one. Also allows passing arguments and environment variables to the new program.
Arguments:
- abi: LinuxRiscv64Abi context
- trapframe: Trapframe containing syscall arguments
Returns:
- 0 on success
- usize::MAX (Linux -1) on error