pub fn sys_flock(abi: &mut LinuxRiscv64Abi, trapframe: &mut Trapframe) -> usizeExpand description
Linux sys_flock - Apply or remove an advisory lock on an open file
Apply or remove an advisory lock on the open file specified by fd. This is a simplified implementation that always succeeds.
Arguments:
- abi: LinuxRiscv64Abi context
- trapframe: Trapframe containing syscall arguments
- arg0: fd (file descriptor)
- arg1: operation (LOCK_SH, LOCK_EX, LOCK_UN, etc.)
Returns:
- 0 on success
- usize::MAX (Linux -1) on error